pub enum NodeAction {
Continue,
Skip,
Drop,
}Expand description
Controls how the sanitizer should handle the current node.
Variants
Continue
Continue with the sanitizer’s normal traversal for this node.
Skip
Keep this node, but skip any deeper sanitization for its children.
Drop
Drop this node entirely.